Struct leo_package::inputs::directory::InputsDirectory [−][src]
Implementations
impl InputsDirectory[src]
pub fn create(path: &Path) -> Result<(), InputsDirectoryError>[src]
Creates a directory at the provided path with the default directory name.
pub fn files(path: &Path) -> Result<Vec<PathBuf>, InputsDirectoryError>[src]
Returns a list of files in the input directory.