Struct leo_package::outputs::proof::ProofFile [−][src]
Fields
package_name: StringImplementations
impl ProofFile[src]
pub fn new(package_name: &str) -> Self[src]
pub fn exists_at(&self, path: &Path) -> bool[src]
pub fn read_from(&self, path: &Path) -> Result<String, ProofFileError>[src]
Reads the proof from the given file path if it exists.
pub fn write_to(&self, path: &Path, proof: &[u8]) -> Result<(), ProofFileError>[src]
Writes the given proof to a file.
pub fn remove(&self, path: &Path) -> Result<bool, ProofFileError>[src]
Removes the proof at the given path if it exists. Returns true on success,
false if the file doesn't exist, and Error if the file system fails during operation.