Struct leo_package::outputs::proving_key::ProvingKeyFile [−][src]
Fields
package_name: StringImplementations
impl ProvingKeyFile[src]
pub fn new(package_name: &str) -> Self[src]
pub fn full_path<'a>(&self, path: &'a Path) -> Cow<'a, Path>[src]
pub fn exists_at(&self, path: &Path) -> bool[src]
pub fn read_from(&self, path: &Path) -> Result<Vec<u8>, ProvingKeyFileError>[src]
Reads the proving key from the given file path if it exists.
pub fn write_to<'a>(
&self,
path: &'a Path,
proving_key: &[u8]
) -> Result<Cow<'a, Path>, ProvingKeyFileError>[src]
&self,
path: &'a Path,
proving_key: &[u8]
) -> Result<Cow<'a, Path>, ProvingKeyFileError>
Writes the given proving key to a file.
pub fn remove(&self, path: &Path) -> Result<bool, ProvingKeyFileError>[src]
Removes the proving key at the given path if it exists. Returns true on success,
false if the file doesn't exist, and Error if the file system fails during operation.