Struct leo_package::outputs::verification_key::VerificationKeyFile [−][src]
Fields
package_name: StringImplementations
impl VerificationKeyFile[src]
pub fn new(package_name: &str) -> Self[src]
pub fn full_path<'a>(&self, path: &'a Path) -> Cow<'a, Path>[src]
pub fn exists_at(&self, path: &Path) -> bool[src]
pub fn read_from(
&self,
path: &Path
) -> Result<Vec<u8>, VerificationKeyFileError>[src]
&self,
path: &Path
) -> Result<Vec<u8>, VerificationKeyFileError>
Reads the verification key from the given file path if it exists.
pub fn write_to<'a>(
&self,
path: &'a Path,
verification_key: &[u8]
) -> Result<Cow<'a, Path>, VerificationKeyFileError>[src]
&self,
path: &'a Path,
verification_key: &[u8]
) -> Result<Cow<'a, Path>, VerificationKeyFileError>
Writes the given verification key to a file.
pub fn remove(&self, path: &Path) -> Result<bool, VerificationKeyFileError>[src]
Removes the verification key at the given path if it exists. Returns true on success,
false if the file doesn't exist, and Error if the file system fails during operation.