Struct leo_package::root::zip::ZipFile[][src]

pub struct ZipFile {
    pub package_name: String,
}

Fields

package_name: String

Implementations

impl ZipFile[src]

pub fn new(package_name: &str) -> Self[src]

pub fn exists_at(&self, path: &Path) -> bool[src]

pub fn get_file_path<'a>(&self, current_dir: &'a Path) -> Cow<'a, Path>[src]

pub fn write(&self, src_dir: &Path) -> Result<(), ZipFileError>[src]

Writes the current package contents to a zip file.

pub fn remove(&self, path: &Path) -> Result<bool, ZipFileError>[src]

Removes the zip file at the given path if it exists. Returns true on success, false if the file doesn't exist, and Error if the file system fails during operation.