pub struct SourceDirectory;Implementations
Sourceimpl SourceDirectory
impl SourceDirectory
Sourcepub fn create(path: &Path) -> Result<()>
pub fn create(path: &Path) -> Result<()>
Creates a directory at the provided path with the default directory name.
Sourcepub fn files(path: &Path) -> Result<Vec<PathBuf>>
pub fn files(path: &Path) -> Result<Vec<PathBuf>>
Returns a list of files in the source directory.
Sourcepub fn check_files(paths: &[PathBuf]) -> Result<()>
pub fn check_files(paths: &[PathBuf]) -> Result<()>
Check that the files in the source directory are valid.