pub struct CompilationUnit {
pub name: Symbol,
pub data: ProgramData,
pub edition: Option<u16>,
pub dependencies: IndexSet<Dependency>,
pub is_local: bool,
pub kind: PackageKind,
}Expand description
Information about a single Leo compilation unit.
Fields
name: Symboldata: ProgramDataedition: Option<u16>dependencies: IndexSet<Dependency>is_local: boolkind: PackageKindImplementations
Sourceimpl CompilationUnit
impl CompilationUnit
Sourcepub fn from_aleo_path<P: AsRef<Path>>(
name: Symbol,
path: P,
map: &IndexMap<Symbol, Dependency>,
) -> Result<Self>
pub fn from_aleo_path<P: AsRef<Path>>( name: Symbol, path: P, map: &IndexMap<Symbol, Dependency>, ) -> Result<Self>
Given the location path of a .aleo file, read the filesystem
to obtain a CompilationUnit.
Sourcepub fn from_package_path<P: AsRef<Path>>(name: Symbol, path: P) -> Result<Self>
pub fn from_package_path<P: AsRef<Path>>(name: Symbol, path: P) -> Result<Self>
Given the location path of a local Leo package, read the filesystem
to obtain a CompilationUnit.
Sourcepub fn from_test_path<P: AsRef<Path>>(
source_path: P,
main_program: Dependency,
) -> Result<Self>
pub fn from_test_path<P: AsRef<Path>>( source_path: P, main_program: Dependency, ) -> Result<Self>
Given the path to the source file of a test, create a CompilationUnit.
Unlike CompilationUnit::from_package_path, the path is to the source file,
and the name of the program is determined from the filename.
main_program must be provided since every test is dependent on it.
Sourcepub fn fetch<P: AsRef<Path>>(
name: Symbol,
edition: Option<u16>,
home_path: P,
network: NetworkName,
endpoint: &str,
no_cache: bool,
network_retries: u32,
) -> Result<Self>
pub fn fetch<P: AsRef<Path>>( name: Symbol, edition: Option<u16>, home_path: P, network: NetworkName, endpoint: &str, no_cache: bool, network_retries: u32, ) -> Result<Self>
Given an Aleo program on a network, fetch it to build a CompilationUnit.
If no edition is found, the latest edition is pulled from the network.