Struct leo_package::source::directory::SourceDirectory[][src]

pub struct SourceDirectory;

Implementations

impl SourceDirectory[src]

pub fn create(path: &Path) -> Result<(), SourceDirectoryError>[src]

Creates a directory at the provided path with the default directory name.

pub fn files(path: &Path) -> Result<Vec<PathBuf>, SourceDirectoryError>[src]

Returns a list of files in the source directory.